==> Gambio v4.1.2.0.zip: Vollversion GX v4.1.2.0/Shopsystem/Dateien/lang/german/original_sections/admin/voucher/coupon_admin.lang.inc.php <==
<?php
/* --------------------------------------------------------------
	coupon_admin.lang.inc.php 2019-06-13
	Gambio GmbH
	http://www.gambio.de
	Copyright (c) 2019 Gambio GmbH
	Released under the GNU General Public License (Version 2)
	[http://www.gnu.org/licenses/gpl-2.0.html]
   --------------------------------------------------------------
*/

$t_language_text_section_content_array = [
    'COUPON_AMOUNT'                         => 'Coupon Wert',
    'COUPON_AMOUNT_HELP'                    => 'Tragen Sie hier den Rabatt für diesen Coupon ein. Entweder einen festen Betrag oder einen prozentualen Rabatt, wie z. B. 10%',
    'COUPON_CATEGORIES'                     => 'Liste der gültigen Kategorien',
    'COUPON_CATEGORIES_HELP'                => 'Eine durch Komma getrennte Liste von Kategorie-IDs, für die dieser Coupon gültig ist. Ein leeres Feld bedeutet keine Einschränkung.',
    'COUPON_CODE'                           => 'Coupon Code',
    'COUPON_CODE_HELP'                      => 'Hier können Sie einen eigenen Code eintragen (max. 16 Zeichen). Lassen Sie das Feld frei, dann wird dieser Code automatisch generiert.',
    'COUPON_DESC'                           => 'Coupon Beschreibung',
    'COUPON_DESC_HELP'                      => 'Beschreibung des Coupons für den Kunden',
    'COUPON_FINISHDATE'                     => 'gültig bis',
    'COUPON_FINISHDATE_HELP'                => 'Das Datum, an dem der Coupon abläuft',
    'COUPON_FREE_SHIP'                      => 'versandkostenfrei',
    'COUPON_FREE_SHIP_HELP'                 => 'Coupon für eine versandkostenfreie Lieferung. <b>Hinweis:</b> Der Couponwert wird weiterhin berücksichtigt und der Mindestbestellwert bleibt gültig. Funktioniert nicht mit prozentualen Rabatten.',
    'COUPON_MIN_ORDER'                      => 'Coupon Mindestbestellwert',
    'COUPON_MIN_ORDER_HELP'                 => 'Mindestbestellwert, ab dem dieser Coupon gültig ist',
    'COUPON_NAME'                           => 'Coupon Name',
    'COUPON_NAME_HELP'                      => 'Eine Kurzbezeichnung für den Coupon',
    'COUPON_PRODUCTS'                       => 'Liste der gültigen Artikel',
    'COUPON_PRODUCTS_HELP'                  => 'Eine durch Komma getrennte Liste von product_ids, für die dieser Coupon gültig ist. Ein leeres Feld bedeutet keine Einschränkung.',
    'COUPON_STARTDATE'                      => 'gültig ab',
    'COUPON_STARTDATE_HELP'                 => 'Das Datum, ab dem der Coupon gültig ist',
    'COUPON_USES_COUPON'                    => 'Anzahl/Verwendungen pro Coupon',
    'COUPON_USES_COUPON_HELP'               => 'Tragen Sie hier ein, wie oft dieser Coupon eingelöst werden darf. Lassen Sie das Feld frei, dann ist die Benutzung unlimitiert.',
    'COUPON_USES_USER'                      => 'Anzahl/Verwendungen pro Kunde',
    'COUPON_USES_USER_HELP'                 => 'Tragen Sie hier ein, wie oft ein Kunde diesen Coupon einlösen darf. Lassen Sie das Feld frei, dann ist die Benutzung unlimitiert.',
    'CUSTOMER_ID'                           => 'Kunden Nr.',
    'CUSTOMER_NAME'                         => 'Kunden Name',
    'DATE_CREATED'                          => 'erstellt am',
    'DATE_MODIFIED'                         => 'geändert am',
    'ERROR_COUPON_EXISTS'                   => 'Ein Coupon mit den selben Code existiert bereits.',
    'ERROR_NO_COUPON_AMOUNT'                => 'Bitte geben sie einen Coupon Wert an.',
    'ERROR_NO_COUPON_NAME'                  => 'Bitte geben Sie einen Coupon Namen an.',
    'ERROR_NO_CUSTOMER_SELECTED'            => 'Fehler: Kein Kunde ausgewählt.',
    'ERROR_PERCENT_VALUE_AND_FREE_SHIPPING' => 'Eine Kombination aus prozentualem Rabatt und versandkostenfreier Lieferung ist nicht möglich.',
    'GM_VIEW'                               => 'Anzeigen',
    'HEADING_SUB_TITLE'                     => 'Hilfsprogramme',
    'HEADING_TITLE'                         => 'Rabatt Coupons',
    'HEADING_TITLE_STATUS'                  => 'Status: ',
    'IP_ADDRESS'                            => 'IP-Adresse',
    'Coupon_VALUE'                          => 'Coupon Wert',
    'NONE' => 'keine',
	'NOTICE_EMAIL_SENT_TO'                  => 'Notiz: E-Mail versendet an: %s',
    'REDEEM_DATE'                           => 'eingelöst am',
    'TABLE_HEADING_ACTION'                  => 'Aktion',
    'TEXT_ALL_CUSTOMERS'                    => 'Alle Kunden',
    'TEXT_CONFIRM_DELETE'                   => 'Soll dieser Coupon wirklich gelöscht werden?',
    'TEXT_COUPON'                           => 'Coupon Name',
    'TEXT_COUPON_ACTIVE'                    => 'Aktive Coupons',
    'TEXT_COUPON_ALL'                       => 'Alle Coupons',
    'TEXT_COUPON_INACTIVE'                  => 'Inaktive Coupons',
    'TEXT_CUSTOMER'                         => 'Kunde:',
    'TEXT_ENTER_CODE'                       => ' und den Code eingeben ',
    'TEXT_FREE_SHIPPING'                    => 'versandkostenfrei',
    'TEXT_FROM'                             => 'von:',
    'TEXT_HEADING_NEW_COUPON'               => 'Neuen Coupon erstellen',
    'TEXT_IN_CASE'                          => ' Falls es wider Erwarten zu Problemen beim Verbuchen kommen sollte.',
    'TEXT_MESSAGE'                          => 'Nachricht:',
    'TEXT_NEWSLETTER_CUSTOMERS'             => 'Alle Newsletter-Abonnenten',
    'TEXT_NEW_INTRO'                        => 'Bitte geben Sie die folgende Informationen für den neuen Coupon an.<br />',
    'TEXT_NO_FREE_SHIPPING'                 => 'Nicht versandkostenfrei',
    'TEXT_REDEMPTIONS'                      => 'Einlösung',
    'TEXT_REDEMPTIONS_CUSTOMER'             => 'Für diesen Kunden',
    'TEXT_REDEMPTIONS_TOTAL'                => 'Insgesamt',
    'TEXT_REMEMBER'                         => 'Bewahren Sie Ihren Gutschein-Code gut auf, damit Sie von diesem Angebot profitieren können',
    'TEXT_SELECT_CUSTOMER'                  => 'Kunde auswählen',
    'TEXT_SUBJECT'                          => 'Betreff:',
    'TEXT_TO_REDEEM'                        => 'Sie können den Gutschein bei Ihrer Bestellung einlösen. Dazu geben Sie Ihren Gutschein-Code in das dafür vorgesehene Feld ein und klicken den "Einlösen"-Button.',
    'TEXT_VOUCHER_IS'                       => 'Ihr Gutschein-Code lautet: ',
    'TOP_BAR_TITLE'                         => 'Statistik',
    'VOUCHER_NUMBER_USED'                   => 'Anzahl Verwendet',
];

==> Gambio v4.5.2.2.zip: Vollversion GX v4.5.2.2/Shopsystem/Dateien/lang/german/original_sections/admin/voucher/coupon_admin.lang.inc.php <==
<?php
/* --------------------------------------------------------------
	coupon_admin.lang.inc.php 2019-06-13
	Gambio GmbH
	http://www.gambio.de
	Copyright (c) 2019 Gambio GmbH
	Released under the GNU General Public License (Version 2)
	[http://www.gnu.org/licenses/gpl-2.0.html]
   --------------------------------------------------------------
*/

$t_language_text_section_content_array = [
    'COUPON_AMOUNT'                         => 'Coupon Wert',
    'COUPON_AMOUNT_HELP'                    => 'Trage hier den Rabatt für diesen Coupon ein. Entweder einen festen Betrag oder einen prozentualen Rabatt, wie z. B. 10%',
    'COUPON_CATEGORIES'                     => 'Liste der gültigen Kategorien',
    'COUPON_CATEGORIES_HELP'                => 'Eine durch Komma getrennte Liste von Kategorie-IDs, für die dieser Coupon gültig ist. Ein leeres Feld bedeutet keine Einschränkung.',
    'COUPON_CODE'                           => 'Coupon Code',
    'COUPON_CODE_HELP'                      => 'Hier kannst du einen eigenen Code eintragen (max. 16 Zeichen). Wenn du das Feld frei lässt, wird der Code automatisch generiert.',
    'COUPON_DESC'                           => 'Coupon Beschreibung',
    'COUPON_DESC_HELP'                      => 'Beschreibung des Coupons für den Kunden',
    'COUPON_FINISHDATE'                     => 'gültig bis',
    'COUPON_FINISHDATE_HELP'                => 'Das Datum, an dem der Coupon abläuft',
    'COUPON_FREE_SHIP'                      => 'versandkostenfrei',
    'COUPON_FREE_SHIP_HELP'                 => 'Coupon für eine versandkostenfreie Lieferung. <b>Hinweis:</b> Der Couponwert wird weiterhin berücksichtigt und der Mindestbestellwert bleibt gültig. Funktioniert nicht mit prozentualen Rabatten.',
    'COUPON_MIN_ORDER'                      => 'Coupon Mindestbestellwert',
    'COUPON_MIN_ORDER_HELP'                 => 'Mindestbestellwert, ab dem dieser Coupon gültig ist',
    'COUPON_NAME'                           => 'Coupon Name',
    'COUPON_NAME_HELP'                      => 'Eine Kurzbezeichnung für den Coupon',
    'COUPON_PRODUCTS'                       => 'Liste der gültigen Artikel',
    'COUPON_PRODUCTS_HELP'                  => 'Eine durch Komma getrennte Liste von product_ids, für die dieser Coupon gültig ist. Ein leeres Feld bedeutet keine Einschränkung.',
    'COUPON_STARTDATE'                      => 'gültig ab',
    'COUPON_STARTDATE_HELP'                 => 'Das Datum, ab dem der Coupon gültig ist',
    'COUPON_USES_COUPON'                    => 'Anzahl/Verwendungen pro Coupon',
    'COUPON_USES_COUPON_HELP'               => 'Trage hier ein, wie oft dieser Coupon eingelöst werden darf. Wenn du das Feld frei lässt, ist die Benutzung unlimitiert.',
    'COUPON_USES_USER'                      => 'Anzahl/Verwendungen pro Kunde',
    'COUPON_USES_USER_HELP'                 => 'Trage hier ein, wie oft ein Kunde diesen Coupon einlösen darf. Wenn du das Feld frei lässt, ist die Benutzung unlimitiert.',
    'CUSTOMER_ID'                           => 'Kunden Nr.',
    'CUSTOMER_NAME'                         => 'Kunden Name',
    'DATE_CREATED'                          => 'erstellt am',
    'DATE_MODIFIED'                         => 'geändert am',
    'ERROR_COUPON_EXISTS'                   => 'Ein Coupon mit diesem Code existiert bereits.',
    'ERROR_NO_COUPON_AMOUNT'                => 'Bitte gib einen Coupon Wert an.',
    'ERROR_NO_COUPON_NAME'                  => 'Bitte gib einen Coupon Namen an.',
    'ERROR_NO_CUSTOMER_SELECTED'            => 'Fehler: Kein Kunde ausgewählt.',
    'ERROR_PERCENT_VALUE_AND_FREE_SHIPPING' => 'Eine Kombination aus prozentualem Rabatt und versandkostenfreier Lieferung ist nicht möglich.',
    'GM_VIEW'                               => 'Anzeigen',
    'HEADING_SUB_TITLE'                     => 'Hilfsprogramme',
    'HEADING_TITLE'                         => 'Rabatt Coupons',
    'HEADING_TITLE_STATUS'                  => 'Status: ',
    'IP_ADDRESS'                            => 'IP-Adresse',
    'Coupon_VALUE'                          => 'Coupon Wert',
    'NONE' => 'keine',
	'NOTICE_EMAIL_SENT_TO'                  => 'Notiz: E-Mail versendet an: %s',
    'REDEEM_DATE'                           => 'eingelöst am',
    'TABLE_HEADING_ACTION'                  => 'Aktion',
    'TEXT_ALL_CUSTOMERS'                    => 'Alle Kunden',
    'TEXT_CONFIRM_DELETE'                   => 'Soll dieser Coupon wirklich gelöscht werden?',
    'TEXT_COUPON'                           => 'Coupon Name',
    'TEXT_COUPON_ACTIVE'                    => 'Aktive Coupons',
    'TEXT_COUPON_ALL'                       => 'Alle Coupons',
    'TEXT_COUPON_INACTIVE'                  => 'Inaktive Coupons',
    'TEXT_CUSTOMER'                         => 'Kunde:',
    'TEXT_ENTER_CODE'                       => ' und den Code eingeben ',
    'TEXT_FREE_SHIPPING'                    => 'versandkostenfrei',
    'TEXT_FROM'                             => 'von:',
    'TEXT_HEADING_NEW_COUPON'               => 'Neuen Coupon erstellen',
    'TEXT_IN_CASE'                          => 'Falls es wider Erwarten zu Problemen beim Verbuchen kommen sollte.',
    'TEXT_MESSAGE'                          => 'Nachricht:',
    'TEXT_NEWSLETTER_CUSTOMERS'             => 'Alle Newsletter-Abonnenten',
    'TEXT_NEW_INTRO'                        => 'Bitte gib die folgenden Informationen für den neuen Coupon an.<br />',
    'TEXT_NO_FREE_SHIPPING'                 => 'Nicht versandkostenfrei',
    'TEXT_REDEMPTIONS'                      => 'Einlösung',
    'TEXT_REDEMPTIONS_CUSTOMER'             => 'Für diesen Kunden',
    'TEXT_REDEMPTIONS_TOTAL'                => 'Insgesamt',
    'TEXT_REMEMBER'                         => 'Bewahren Sie Ihren Gutschein-Code gut auf, damit Sie von diesem Angebot profitieren können',
    'TEXT_SELECT_CUSTOMER'                  => 'Kunde auswählen',
    'TEXT_SUBJECT'                          => 'Betreff:',
    'TEXT_TO_REDEEM'                        => 'Sie können den Gutschein bei Ihrer Bestellung einlösen. Dazu geben Sie Ihren Gutschein-Code in das dafür vorgesehene Feld ein und klicken den "Einlösen"-Button.',
    'TEXT_VOUCHER_IS'                       => 'Ihr Gutschein-Code lautet: ',
    'TOP_BAR_TITLE'                         => 'Statistik',
    'VOUCHER_NUMBER_USED'                   => 'Anzahl Verwendet',
];
